@@ -5,9 +5,12 @@ from localstack.services.plugins import Service, aws_provider
 
 @aws_provider()
 def acm():
-    from localstack.services.acm import acm_starter
+    from localstack.services.acm.provider import AcmProvider
+    from localstack.services.moto import MotoFallbackDispatcher
 
-    return Service("acm", start=acm_starter.start_acm)
+    provider = AcmProvider()
+
+    return Service("acm", listener=AwsApiListener("acm", MotoFallbackDispatcher(provider)))
 
 
 @aws_provider()
@@ -250,9 +253,14 @@ def sqs_asf():
 
 @aws_provider()
 def ssm():
-    from localstack.services.ssm import ssm_listener, ssm_starter
+    from localstack.services.moto import MotoFallbackDispatcher
+    from localstack.services.ssm.provider import SsmProvider
 
-    return Service("ssm", listener=ssm_listener.UPDATE_SSM, start=ssm_starter.start_ssm)
+    provider = SsmProvider()
+    return Service(
+        "ssm",
+        listener=AwsApiListener("ssm", MotoFallbackDispatcher(provider)),
+    )
 
 
 @aws_provider()
@@ -278,22 +286,27 @@ def stepfunctions():
 
 @aws_provider()
 def swf():
-    from localstack.services.swf import swf_starter
+    from localstack.services.moto import MotoFallbackDispatcher
+    from localstack.services.swf.provider import SWFProvider
 
+    provider = SWFProvider()
     return Service(
         "swf",
-        start=swf_starter.start_swf,
+        listener=AwsApiListener("swf", MotoFallbackDispatcher(provider)),
     )
 
 
 @aws_provider()
 def resourcegroupstaggingapi():
-    from localstack.services.resourcegroupstaggingapi import rgta_listener, rgta_starter
+    from localstack.services.moto import MotoFallbackDispatcher
+    from localstack.services.resourcegroupstaggingapi.provider import (
+        ResourcegroupstaggingapiProvider,
+    )
 
+    provider = ResourcegroupstaggingapiProvider()
     return Service(
         "resourcegroupstaggingapi",
-        listener=rgta_listener.UPDATE_RGSA,
-        start=rgta_starter.start_rgsa,
+        listener=AwsApiListener("resourcegroupstaggingapi", MotoFallbackDispatcher(provider)),
     )
 
 
@@ -306,6 +319,11 @@ def resource_groups():
 
 @aws_provider()
 def support():
-    from localstack.services.support import support_starter
+    from localstack.services.moto import MotoFallbackDispatcher
+    from localstack.services.support.provider import SupportProvider
 
-    return Service("support", start=support_starter.start_support)
+    provider = SupportProvider()
+    return Service(
+        "support",
+        listener=AwsApiListener("support", MotoFallbackDispatcher(provider)),
+    )
