@@ -7,23 +7,24 @@ import signal
 import threading
 import warnings
 from functools import wraps
-from typing import Iterable, List, Optional, Set
+from typing import Dict, Iterable, List, Optional, Set
 
 from localstack import config, constants
 from localstack.config import Directories
 from localstack.runtime import hooks
 from localstack.utils.common import FileListener, chmod_r, mkdir, poll_condition
-from localstack.utils.docker_utils import (
-    DOCKER_CLIENT,
-    CmdDockerClient,
+from localstack.utils.container_utils.container_client import (
     ContainerException,
     PortMappings,
     SimpleVolumeBind,
     VolumeBind,
     VolumeMappings,
 )
+from localstack.utils.container_utils.docker_cmd_client import CmdDockerClient
+from localstack.utils.docker_utils import DOCKER_CLIENT
 
 # set up logger
+from localstack.utils.generic.file_utils import cache_dir
 from localstack.utils.run import run, to_str
 from localstack.utils.serving import Server
 
@@ -38,7 +39,7 @@ LOG_DATE_FORMAT = "%Y-%m-%dT%H:%M:%S"
 API_DEPENDENCIES = {
     "dynamodb": ["dynamodbstreams"],
     "dynamodbstreams": ["kinesis"],
-    "es": ["elasticsearch"],
+    "es": ["opensearch"],
     "lambda": ["logs", "cloudwatch"],
     "kinesis": ["dynamodb"],
     "firehose": ["kinesis"],
@@ -89,7 +90,7 @@ def log_duration(name=None, min_ms=500):
     return wrapper
 
 
-def get_docker_image_details(image_name=None):
+def get_docker_image_details(image_name: str = None) -> Dict[str, str]:
     image_name = image_name or get_docker_image_to_start()
     try:
         result = DOCKER_CLIENT.inspect_image(image_name)
@@ -130,7 +131,19 @@ def get_main_container_name():
     return MAIN_CONTAINER_NAME_CACHED
 
 
-def get_server_version():
+def get_image_environment_variable(env_name: str) -> Optional[str]:
+    image_name = get_docker_image_to_start()
+    image_info = DOCKER_CLIENT.inspect_image(image_name)
+    image_envs = image_info["Config"]["Env"]
+
+    try:
+        found_env = next(env for env in image_envs if env.startswith(env_name))
+    except StopIteration:
+        return None
+    return found_env.split("=")[1]
+
+
+def get_server_version_from_running_container() -> str:
     try:
         # try to extract from existing running container
         container_name = get_main_container_name()
@@ -157,6 +170,26 @@ def get_server_version():
             return constants.VERSION
 
 
+def get_server_version() -> str:
+    image_hash = get_docker_image_details()["id"]
+    version_cache = cache_dir() / "image_metadata" / image_hash / "localstack_version"
+    if version_cache.exists():
+        cached_version = version_cache.read_text()
+        return cached_version.strip()
+
+    env_version = get_image_environment_variable("LOCALSTACK_BUILD_VERSION")
+    if env_version is not None:
+        version_cache.parent.mkdir(exist_ok=True, parents=True)
+        version_cache.write_text(env_version)
+        return env_version
+
+    container_version = get_server_version_from_running_container()
+    version_cache.parent.mkdir(exist_ok=True, parents=True)
+    version_cache.write_text(container_version)
+
+    return container_version
+
+
 def setup_logging(log_level=None):
     """Determine and set log level"""
 
@@ -276,7 +309,6 @@ def canonicalize_api_names(apis: Iterable[str] = None) -> List[str]:
     for api in apis:
         if api not in config.SERVICE_PORTS:
             config.SERVICE_PORTS[api] = config.DEFAULT_SERVICE_PORTS.get(api)
-    config.populate_configs(config.SERVICE_PORTS)
 
     return list(apis)
 
@@ -429,6 +461,7 @@ def extract_port_flags(user_flags, port_mappings: PortMappings):
     return user_flags
 
 
+# TODO merge with docker_utils.py:ContainerConfiguration
 class LocalstackContainer:
     name: str
     image_name: str
@@ -448,7 +481,7 @@ class LocalstackContainer:
     logfile: Optional[str] = None
     stdin: Optional[str] = None
     user: Optional[str] = None
-    cap_add: Optional[str] = None
+    cap_add: Optional[List[str]] = None
     network: Optional[str] = None
     dns: Optional[str] = None
     workdir: Optional[str] = None
@@ -563,10 +596,11 @@ def prepare_docker_start():
     if DOCKER_CLIENT.is_container_running(container_name):
         raise ContainerExists('LocalStack container named "%s" is already running' % container_name)
     if config.dirs.tmp != config.dirs.functions and not config.LAMBDA_REMOTE_DOCKER:
+        # Logger is not initialized at this point, so the warning is displayed via print
         print(
             f"WARNING: The detected temp folder for localstack ({config.dirs.tmp}) is not equal to the "
             f"HOST_TMP_FOLDER environment variable set ({config.dirs.functions})."
-        )  # Logger is not initialized at this point, so the warning is displayed via print
+        )
 
     os.environ[ENV_SCRIPT_STARTING_DOCKER] = "1"
 
@@ -597,6 +631,8 @@ def configure_container(container: LocalstackContainer):
     for port in service_ports.values():
         if port:
             container.ports.add(port)
+    for port in range(config.EXTERNAL_SERVICE_PORTS_START, config.EXTERNAL_SERVICE_PORTS_END):
+        container.ports.add(port)
 
     if config.DEVELOP:
         container.ports.add(config.DEVELOP_PORT)
